@@ -1,4 +1,3 @@
-
 # Copyright (c) 2022 Mingoo Lee
 
 # Permission is hereby granted, free of charge, to any person obtaining
@@ -20,13 +19,4 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-from .pipcontrol import *
-
-__all__ = [
-    "install",
-    "uninstall",
-    "requirement_install",
-    "requirement_uninstall",
-    "requirement_freeze",
-]
-
+from pipcontrol import PipControl
